{
 *  IRCDelphi - an Internet Relay Chat Daemon, irc_const.pas
 *
 *  Copyright (C) 2001-2003 by the past and present ircd coders, and others.
 *  Refer to the documentation within doc/ for full credits and copyrights.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 *  USA
 *
}

///////////////////////////////////////////////////////////////////////////////
//      ᠭ ᢮ ᮡ⢥ ࢥ 
// IRC.  ᮡ࠭ 騥 ⠭   ⢥⮢  ⢥, 묨 
//   ࢥ.     ⠭   RFC1459.
//                       For foreign developers
//This module can be useful when you writing your own IRC server or client. 
//General constants, codes of answers and answers, which are changed the client 
//and server are here. Not all from available constants there are in RFC1459.
///////////////////////////////////////////////////////////////////////////////
// Look for RPL_TOPICTIME, RPL_CHANNELCREATE. They are absent in RFC.

unit irc_const;
interface

// Temporary server info
Const
      MENAME  = 'IRCDelphi.LocalNet.net';
      MEDESCRIPTION = 'IRCDelphi/32 0.0.0.0a3 Smirnoff';
      MEADMINNAME = 'Christiano Becker';
      MEADMINEMAIL = 'zoinho@tarolando.com';
      MEADMININFO = 'zoinho - #IRCDelphi';
      MEPORT = 6667;
      MENETWORK = 'IRCDelphi';

//Modes of channel and user
Const
   chan_modes: Array [1..11] of string =
  ('b','i','k','l','m','n','o','p','s','t','v');

   user_modes: Array [1..7] of string =
  ('o','i','w','s','O','R','D');

//Irc consts
Const
      HOSTLEN       = 254;
      NICKLEN       = 30;
      USERLEN       = 10;
      REALLEN       = 50;
      TOPICLEN      = 254;
      KICKLEN       = 254;
      CHANNELLEN    = 32;
      PASSWDLEN     = 32;
      KEYLEN        = 23;
      MAXRECIPIENTS = 20;
      MAXBANS       = 60;
      MAXBANLENGTH  = 1024;
      BANLEN        = (USERLEN + NICKLEN + HOSTLEN + 3);
      MAXPENALTY    = 10;
      MAXCHANNELS   = 10;
//Replies of server
Const
    // Witanium
    STS_VERSION = 'IRCDelphi/32 0.0.0.0a3 Smirnoff';
    STS_DATECREATE = 'Thu Sep 7 2003 at 15:44:00 BRT';
    STS_INFO = '[%s] [info] -=-=[ %s ]=-=-';
    STS_ALERT = '[%s] [ALERT] *** %s ***';

    BREPORT_DO_DNS	= 'NOTICE AUTH :*** Looking up your hostname...';
    BREPORT_FIN_DNS	= 'NOTICE AUTH :*** Found your hostname';
    BREPORT_FAIL_DNS = 'NOTICE AUTH :*** Couldn''t resolve your hostname; using your IP address instead';


    ERR_NOSUCHNICK = 401;
    MSG_NOSUCHNICK = '%s :No such nick/channel';
            {%s = <nickname>
            - Used to indicate the nickname parameter supplied to a
              command is currently unused.}

    ERR_NOSUCHSERVER = 402;
    MSG_NOSUCHSERVER = '%s :No such server';
           {%s = <server name>
            - Used to indicate the server name given currently
              doesn't exist.}

    ERR_NOSUCHCHANNEL = 403;
    MSG_NOSUCHCHANNEL = '%s :No such channel';
            {%s = <channel name>
            - Used to indicate the given channel name is invalid.
            }
    ERR_CANNOTSENDTOCHAN = 404;
    MSG_CANNOTSENDTOCHAN = '%s :Cannot send to channel';
            {%s = <channel name>
            - Sent to a user who is either (a) not on a channel
              which is mode +n or (b) not a chanop (or mode +v) on
              a channel which has mode +m set and is trying to send
              a PRIVMSG message to that channel.
             }
    ERR_TOOMANYCHANNELS = 405;
    MSG_TOOMANYCHANNELS = '%s :You have joined too many channels';
            {%s = <channel name>
            - Sent to a user when they have joined the maximum
              number of allowed channels and they try to join
              another channel.
            }
    ERR_WASNOSUCHNICK = 406;
    MSG_WASNOSUCHNICK = '%s :There was no such nickname';
            {%s = <nickname>
            - Returned by WHOWAS to indicate there is no history
              information for that nickname.
            }
    ERR_TOOMANYTARGETS = 407;
    MSG_TOOMANYTARGETS = '%s :Duplicate recipients. No message delivered';
            {%s = <target>
            - Returned to a client which is attempting to send a
              PRIVMSG/NOTICE using the user@host destination format
              and for a user@host which has several occurrences.
             }
    ERR_NOORIGIN = 409;
    MSG_NOORIGIN = ':No origin specified';
            {
            - PING or PONG message missing the originator parameter
              which is required since these commands must work
              without valid prefixes.
             }
    ERR_NORECIPIENT = 411;
    MSG_NORECIPIENT = ':No recipient given (%s)';
             {%s = <command>}
    ERR_NOTEXTTOSEND = 412;
    MSG_NOTEXTTOSEND = ':No text to send';
    ERR_NOTOPLEVEL = 413;
    MSG_NOTOPLEVEL = '%s :No toplevel domain specified';
              {%s = <mask>}
    ERR_WILDTOPLEVEL = 414;
    MSG_WILDTOPLEVEL = '%s :Wildcard in toplevel domain';
              {%s = <mask>
            - 412 - 414 are returned by PRIVMSG to indicate that
              the message wasn't delivered for some reason.
              ERR_NOTOPLEVEL and ERR_WILDTOPLEVEL are errors that
              are returned when an invalid use of
              'PRIVMSG $<server>' or 'PRIVMSG #<host>' is attempted.
               }
    ERR_UNKNOWNCOMMAND = 421;
    MSG_UNKNOWNCOMMAND = '%s :Unknown command';
              {%s = <command>
            - Returned to a registered client to indicate that the
              command sent is unknown by the server.
               }
    ERR_NOMOTD = 422;
    MSG_NOMOTD = ':MOTD File is missing';
              {
            - Server's MOTD file could not be opened by the server.
              }
    ERR_NOADMININFO = 423;
    MSG_NOADMININFO = '%s :No administrative info available';
              {%s = <server>
            - Returned by a server in response to an ADMIN message
              when there is an error in finding the appropriate
              information.
              }
    ERR_FILEERROR = 424;
    MSG_FILEERROR = ':File error doing %s on %s';
              {%s = <file op>; %s = <file>
            - Generic error message used to report a failed file
              operation during the processing of a message.
              }
    ERR_NONICKNAMEGIVEN = 431;
    MSG_NONICKNAMEGIVEN = ':No nickname given';
              {
            - Returned when a nickname parameter expected for a
              command and isn't found.
              }
    ERR_ERRONEUSNICKNAME = 432;
    MSG_ERRONEUSNICKNAME = '%s :Erroneus nickname';
              {%s = <nick>
            - Returned after receiving a NICK message which contains
              characters which do not fall in the defined set.  See
              section x.x.x for details on valid nicknames.
              }
    ERR_NICKNAMEINUSE = 433;
    MSG_NICKNAMEINUSE = '%s :Nickname is already in use';
              {%s = <nick>
            - Returned when a NICK message is processed that results
              in an attempt to change to a currently existing
              nickname.
              }
    ERR_NICKCOLLISION = 436;
    MSG_NICKCOLLISION = '%s :Nickname collision KILL';
             {%s = <nick>
            - Returned by a server to a client when it detects a
              nickname collision (registered of a NICK that
              already exists by another server).
             }
    ERR_USERNOTINCHANNEL = 441;
    MSG_USERNOTINCHANNEL = '%s %s :They aren''t on that channel';
             {%s = <nick>; %s = <channel>
            - Returned by the server to indicate that the target
              user of the command is not on the given channel.
             }
    ERR_NOTONCHANNEL = 442;
    MSG_NOTONCHANNEL = '%s :You''re not on that channel';
             {%s = <channel>
            - Returned by the server whenever a client tries to
              perform a channel effecting command for which the
              client isn't a member.
             }
    ERR_USERONCHANNEL = 443;
    MSG_USERONCHANNEL = '%s %s :is already on channel';
            {%s = <user>; %s = <channel>
            - Returned when a client tries to invite a user to a
              channel they are already on.
            }
    ERR_NOLOGIN = 444;
    MSG_NOLOGIN = '%s :User not logged in';
           {%s = <user>
            - Returned by the summon after a SUMMON command for a
              user was unable to be performed since they were not
              logged in.
           }
    ERR_SUMMONDISABLED = 445;
    MSG_SUMMONDISABLED = ':SUMMON has been disabled';
           {
            - Returned as a response to the SUMMON command.  Must be
              returned by any server which does not implement it.
           }
    ERR_USERSDISABLED = 446;
    MSG_USERSDISABLED = ':USERS has been disabled';
           {
            - Returned as a response to the USERS command.  Must be
              returned by any server which does not implement it.
           }
    ERR_NOTREGISTERED = 451;
    MSG_NOTREGISTERED = ':You have not registered';
           {
            - Returned by the server to indicate that the client
              must be registered before the server will allow it
              to be parsed in detail.
           }
    ERR_NEEDMOREPARAMS = 461;
    MSG_NEEDMOREPARAMS = '%s :Not enough parameters';
           {%s = <command>
            - Returned by the server by numerous commands to
              indicate to the client that it didn't supply enough
              parameters.
           }
    ERR_ALREADYREGISTRED = 462;
    MSG_ALREADYREGISTRED = ':You may not reregister';
            {
            - Returned by the server to any link which tries to
              change part of the registered details (such as
              password or user details from second USER message).
            }
    ERR_NOPERMFORHOST = 463;
    MSG_NOPERMFORHOST = ':Your host isn''t among the privileged';
            {
            - Returned to a client which attempts to register with
              a server which does not been setup to allow
              connections from the host the attempted connection
              is tried.
            }
    ERR_PASSWDMISMATCH = 464;
    MSG_PASSWDMISMATCH = ':Password incorrect';
            {
            - Returned to indicate a failed attempt at registering
              a connection for which a password was required and
              was either not given or incorrect.
            }
    ERR_YOUREBANNEDCREEP = 465;
    MSG_YOUREBANNEDCREEP =  ':You are banned from this server';
            {
            - Returned after an attempt to connect and register
              yourself with a server which has been setup to
              explicitly deny connections to you.
            }
    ERR_KEYSET = 467;
    MSG_KEYSET = '%s :Channel key already set';
            {%s = <channel>}
    ERR_CHANNELISFULL = 471;
    MSG_CHANNELISFULL = '%s :Cannot join channel (+l). The channel is full.';
            {%s = <channel>}
    ERR_UNKNOWNMODE = 472;
    MSG_UNKNOWNMODE = '%s :is unknown mode char to me';
            {%s = <char>}
    ERR_INVITEONLYCHAN = 473;
    MSG_INVITEONLYCHAN = '%s :Cannot join channel (+i)';
            {%s = <channel>}
    ERR_BANNEDFROMCHAN = 474;
    MSG_BANNEDFROMCHAN = '%s :Cannot join channel (+b)';
            {%s = <channel>}
    ERR_BADCHANNELKEY = 475;
    MSG_BADCHANNELKEY = '%s :Cannot join channel (+k). You the correct key.';
            {%s = <channel>}
    ERR_NOPRIVILEGES = 481;
    MSG_NOPRIVILEGES = ':Permission Denied- You''re not an IRC operator';
            {
            - Any command requiring operator privileges to operate
              must return this error to indicate the attempt was
              unsuccessful.
            }
    ERR_CHANOPRIVSNEEDED = 482;
    MSG_CHANOPRIVSNEEDED = '%s :You''re not channel operator';
            {%s = <channel>;
            - Any command requiring 'chanop' privileges (such as
              MODE messages) must return this error if the client
              making the attempt is not a chanop on the specified
              channel.
             }
    ERR_CANTKILLSERVER = 483;
    MSG_CANTKILLSERVER = ':You cant kill a server!';
            {
            - Any attempts to use the KILL command on a server
              are to be refused and this error returned directly
              to the client.
            }
    ERR_NOOPERHOST = 491;
    MSG_NOOPERHOST = ':No O-lines for your host';
            {
            - If a client sends an OPER message and the server has
              not been configured to allow connections from the
              client's host as an operator, this error must be
              returned.
            }
    ERR_UMODEUNKNOWNFLAG = 501;
    MSG_UMODEUNKNOWNFLAG = ':Unknown MODE flag %s';
            {%s = <flag>
            - Returned by the server to indicate that a MODE
              message was sent with a nickname parameter and that
              the a mode flag sent was not recognized.
            }
    ERR_USERSDONTMATCH = 502;
    MSG_USERSDONTMATCH = ':Cant change mode for other users';
            {
            - Error sent to any user trying to view or change the
              user mode for a user other than themselves.
            }
{ Command responses. }

    RPL_NONE = 300;
            {
             Dummy reply number. Not used.
            }
    RPL_USERHOST = 302;
    MSG_USERHOST = ':%s=%s';
            {%s = nick; %s = hostname]
            - Reply format used by USERHOST to list replies to
              the query list.  The reply string is composed as
              follows:

              <reply> ::= <nick>['*'] '=' <'+'|'-'><hostname>

              The '*' indicates whether the client has registered
              as an Operator.  The '-' or '+' characters represent
              whether the client has set an AWAY message or not
              respectively.
           }
    RPL_ISON = 303;
    MSG_ISON = ':%s';
           {%s = [<nick> (<space><nick>)]
            - Reply format used by ISON to list replies to the
              query list.
           }
    RPL_AWAY = 301;
    MSG_AWAY = '%s :%s';
           {%s = <nick>; %s = <away message>}
    RPL_UNAWAY = 305;
    MSG_UNAWAY = ':You are no longer marked as being away';
    RPL_NOWAWAY = 306;
    MSG_NOWAWAY = ':You have been marked as being away';
            {
            - These replies are used with the AWAY command (if
              allowed).  RPL_AWAY is sent to any client sending a
              PRIVMSG to a client which is away.  RPL_AWAY is only
              sent by the server to which the client is connected.
              Replies RPL_UNAWAY and RPL_NOWAWAY are sent when the
              client removes and sets an AWAY message.
            }
    RPL_WHOISUSER = 311;
    MSG_WHOISUSER = '%s %s %s * :%s';
            {%s = <nick>; %s = <user>; %s = <host>; %s = <real name>}
    RPL_WHOISSERVER = 312;
    MSG_WHOISSERVER = '%s %s :%s';
            {%s = <nick>; %s = <server>; %s = <server info>}
    RPL_WHOISOPERATOR = 313;
    MSG_WHOISOPERATOR = '%s :is an IRC operator';
            {%s = <nick>}
    RPL_WHOISIDLE = 317;
    MSG_WHOISIDLE = '%s %d :seconds idle';
            {%s = <nick>; %s = <integer>}
    RPL_ENDOFWHOIS = 318;
    MSG_ENDOFWHOIS = '%s :End of /WHOIS list';
            {%s = <nick>}
    RPL_WHOISCHANNELS = 319;
    MSG_WHOISCHANNELS = '%s :%s';
            {%s = <nick>; %s = ([@|+]<channel><space>)
            - Replies 311 - 313, 317 - 319 are all replies
              generated in response to a WHOIS message.  Given that
              there are enough parameters present, the answering
              server must either formulate a reply out of the above
              numerics (if the query nick is found) or return an
              error reply.  The '*' in RPL_WHOISUSER is there as
              the literal character and not as a wild card.  For
              each reply set, only RPL_WHOISCHANNELS may appear
              more than once (for long lists of channel names).
              The '@' and '+' characters next to the channel name
              indicate whether a client is a channel operator or
              has been granted permission to speak on a moderated
              channel.  The RPL_ENDOFWHOIS reply is used to mark
              the end of processing a WHOIS message.
             }
    RPL_WHOWASUSER = 314;
    MSG_WHOWASUSER = '%s %s %s * :%s';
            {%s = <nick>; %s = <user>; %s = <host>; %s = <real name>}
    RPL_ENDOFWHOWAS = 369;
    MSG_ENDOFWHOWAS = '%s :End of WHOWAS';
            {%s = <nick>
            - When replying to a WHOWAS message, a server must use
              the replies RPL_WHOWASUSER, RPL_WHOISSERVER or
              ERR_WASNOSUCHNICK for each nickname in the presented
              list.  At the end of all reply batches, there must
              be RPL_ENDOFWHOWAS (even if there was only one reply
              and it was an error).
             }
    RPL_LISTSTART = 321;
    MSG_LISTSTART = 'Channel :Users  Name';
    RPL_LIST = 322;
    MSG_LIST = '%s';
             {%s = "<channel> <# visible> :<topic>"}
    RPL_LISTEND = 323;
    MSG_LISTEND = ':End of /LIST';
             {
            - Replies RPL_LISTSTART, RPL_LIST, RPL_LISTEND mark
              the start, actual replies with data and end of the
              server's response to a LIST command.  If there are
              no channels available to return, only the start
              and end reply must be sent.
             }
    RPL_CHANNELMODEIS = 324;
    MSG_CHANNELMODEIS = '%s %s %s';
             {%s = <channel>; %s = <mode>; %s = <mode params>}
    RPL_CHANNELCREATE = 329;
    MSG_CHANNELCREATE = '%s %d';
             {%s = <channel> %d = <time>}
    RPL_NOTOPIC = 331;
    MSG_NOTOPIC = '%s :No topic is set';
             {%s = <channel>}
    RPL_TOPIC = 332;
    MSG_TOPIC = '%s :%s';
             {%s = <channel>; %s = <topic>
            - When sending a TOPIC message to determine the
              channel topic, one of two replies is sent.  If
              the topic is set, RPL_TOPIC is sent back else
              RPL_NOTOPIC.
             }
    RPL_TOPICTIME = 333;
    MSG_TOPICTIME = '%s %s %d';
    { %s = <channel> %s = <topic creater> %d = <topic set time> }
    RPL_INVITING = 341;
    MSG_INVITING = '%s %s';
             {%s = <channel>; %s = <nick>
            - Returned by the server to indicate that the
              attempted INVITE message was successful and is
              being passed onto the end client.
             }
    RPL_SUMMONING = 342;
    MSG_SUMMONING = '%s :Summoning user to IRC';
             {%s = <user>
            - Returned by a server answering a SUMMON message to
              indicate that it is summoning that user.
             }
    RPL_VERSION = 351;
    MSG_VERSION = '%s %s :%s';
             {%s = <version>.<debuglevel>; %s = <server>; %s = <comments>
            - Reply by the server showing its version details.
              The <version> is the version of the software being
              used (including any patchlevel revisions) and the
              <debuglevel> is used to indicate if the server is
              running in 'debug mode'.

              The 'comments' field may contain any comments about
              the version or further version details.
             }
    RPL_WHOREPLY = 352;
    MSG_WHOREPLY = '%s %s %s %s %s %s%s :%d %s';
             {%s = <channel>; %s = <user>; %s = <host>; %s = <server>;
              %s = <nick>; %s = <H|G>; %s = [*][@|+]; %d = <hopcount>;  
              %s = <real name>;
             }
    RPL_ENDOFWHO = 315;
    MSG_ENDOFWHO = '%s :End of /WHO list';
             {%s = <name>
            - The RPL_WHOREPLY and RPL_ENDOFWHO pair are used
              to answer a WHO message.  The RPL_WHOREPLY is only
              sent if there is an appropriate match to the WHO
              query.  If there is a list of parameters supplied
              with a WHO message, a RPL_ENDOFWHO must be sent
              after processing each list item with <name> being
              the item.
             }
    RPL_NAMREPLY = 353;
    MSG_NAMREPLY = '= %s :%s';
             {%s = <channel>; %s = [[@|+]<nick> [[@|+]<nick> [...]]]}
    RPL_ENDOFNAMES = 366;
    MSG_ENDOFNAMES = '%s :End of /NAMES list';
             {%s = <channel>
            - To reply to a NAMES message, a reply pair consisting
              of RPL_NAMREPLY and RPL_ENDOFNAMES is sent by the
              server back to the client.  If there is no channel
              found as in the query, then only RPL_ENDOFNAMES is
              returned.  The exception to this is when a NAMES
              message is sent with no parameters and all visible
              channels and contents are sent back in a series of
              RPL_NAMEREPLY messages with a RPL_ENDOFNAMES to mark
              the end.
             }
    RPL_LINKS = 364;
    MSG_LINKS = '%s %s :%d %s';
             {%s = <mask>; %s = <server>; %d = <hopcount>; %s = <server info>}
    RPL_ENDOFLINKS = 365;
    MSG_ENDOFLINKS = '%s :End of /LINKS list';
             {%s = <mask>
            - In replying to the LINKS message, a server must send
              replies back using the RPL_LINKS numeric and mark the
              end of the list using an RPL_ENDOFLINKS reply.
             }
    RPL_BANLIST = 367;
    MSG_BANLIST = '%s %s %s $d';
             {%s = <channel>; %s = <banid>; %s = <by>; %d = <time>}
    RPL_ENDOFBANLIST = 368;
    MSG_ENDOFBANLIST = '%s :End of channel ban list';
             {%s = <channel>
            - When listing the active 'bans' for a given channel,
              a server is required to send the list back using the
              RPL_BANLIST and RPL_ENDOFBANLIST messages.  A separate
              RPL_BANLIST is sent for each active banid.  After the
              banids have been listed (or if none present) a
              RPL_ENDOFBANLIST must be sent.
             }
    RPL_INFO = 371;
    MSG_INFO = ':%s';
             {%s = <string>}
    RPL_ENDOFINFO = 374;
    MSG_ENDOFINFO = ':End of /INFO list';
             {
            - A server responding to an INFO message is required to
              send all its 'info' in a series of RPL_INFO messages
              with a RPL_ENDOFINFO reply to indicate the end of the
              replies.
             }
    RPL_MOTDSTART = 375;
    MSG_MOTDSTART = ':- %s Message of the day - ';
             {%s = <server>}
    RPL_MOTD = 372;
    MSG_MOTD = ':- %s';
             {%s = <text>}
    RPL_ENDOFMOTD = 376;
    MSG_ENDOFMOTD = ':End of /MOTD command';
             {
            - When responding to the MOTD message and the MOTD file
              is found, the file is displayed line by line, with
              each line no longer than 80 characters, using
              RPL_MOTD format replies.  These should be surrounded
              by a RPL_MOTDSTART (before the RPL_MOTDs) and an
              RPL_ENDOFMOTD (after).
             }
    RPL_YOUREOPER = 381;
    MSG_YOUREOPER = ':You are now an IRC operator';
             {
            - RPL_YOUREOPER is sent back to a client which has
              just successfully issued an OPER message and gained
              operator status.
             }
    RPL_REHASHING = 382;
    MSG_REHASHING = '<config file> :Rehashing';
             {
            - If the REHASH option is used and an operator sends
              a REHASH message, an RPL_REHASHING is sent back to
              the operator.
             }
    RPL_TIME = 391;
    MSG_TIME = '%s :%s';
             {%s = <server>; %s = <string showing server's local time>
            - When replying to the TIME message, a server must send
              the reply using the RPL_TIME format above.  The string
              showing the time need only contain the correct day and
              time there.  There is no further requirement for the
              time string.
            }
    RPL_USERSSTART = 392;
    MSG_USERSSTART = ':UserID   Terminal  Host';
    RPL_USERS = 393;
    MSG_USERS = ':%-8s %-9s %-8s';
    RPL_ENDOFUSERS = 394;
    MSG_ENDOFUSERS = ':End of users';
    RPL_NOUSERS = 395;
    MSG_NOUSERS = ':Nobody logged in';
             {
            - If the USERS message is handled by a server, the
              replies RPL_USERSTART, RPL_USERS, RPL_ENDOFUSERS and
              RPL_NOUSERS are used.  RPL_USERSSTART must be sent
              first, following by either a sequence of RPL_USERS
              or a single RPL_NOUSER.  Following this is
              RPL_ENDOFUSERS.
            }
    RPL_TRACELINK = 200;
    MSG_TRACELINK = 'Link %s %s %s';
           {%s = <version & debug level>; %s = <destination>; %s = <next server>}
    RPL_TRACECONNECTING = 201;
    MSG_TRACECONNECTING = 'Try. %s %s';
           {%s = <class>; %s = <server>}
    RPL_TRACEHANDSHAKE = 202;
    MSG_TRACEHANDSHAKE = 'H.S. %s %s';
           {%s = <class>; %s = <server>}
    RPL_TRACEUNKNOWN = 203;
    MSG_TRACEUNKNOWN = '???? %s %s';
           {%s = <class>; %s = [<client IP address in dot form>]}
    RPL_TRACEOPERATOR = 204;
    MSG_TRACEOPERATOR = 'Oper %s %s';
           {%s = <class>; %s = <nick>}
    RPL_TRACEUSER = 205;
    MSG_TRACEUSER = 'User %s %s';
           {%s = <class>; %s = <nick>}
    RPL_TRACESERVER = 206;
    MSG_TRACESERVER = 'Serv %s %dS %dC %s %s@%s';
           {%s = <class>; %d = <int>; %d = <int>; %s = <server>;
            %s = %s = <nick!user|*!*>; %s = <host|server>}
    RPL_TRACENEWTYPE = 208;
    MSG_TRACENEWTYPE = '%s 0 %s';
           {%s = <newtype>; %s = <client name>}
    RPL_TRACELOG = 261;
    MSG_TRACELOG = 'File %s %s';
           {%s = <logfile>; %s = <debug level>
            - The RPL_TRACE* are all returned by the server in
              response to the TRACE message.  How many are
              returned is dependent on the the TRACE message and
              whether it was sent by an operator or not.  There
              is no predefined order for which occurs first.
              Replies RPL_TRACEUNKNOWN, RPL_TRACECONNECTING and
              RPL_TRACEHANDSHAKE are all used for connections
              which have not been fully established and are either
              unknown, still attempting to connect or in the
              process of completing the 'server handshake'.
              RPL_TRACELINK is sent by any server which handles
              a TRACE message and has to pass it on to another
              server.  The list of RPL_TRACELINKs sent in
              response to a TRACE command traversing the IRC
              network should reflect the actual connectivity of
              the servers themselves along that path.
              RPL_TRACENEWTYPE is to be used for any connection
              which does not fit in the other categories but is
              being displayed anyway.
            }
    RPL_STATSLINKINFO = 211;
    MSG_STATSLINKINFO = '%s %d %s %d %s %d %d';
            {%s = <linkname>; %d = <sendq>; %s = <sent messages>; %d = <sent bytes>;
             %s = <received messages>; %d = <received bytes>; %d = <time open>}
    RPL_STATSCOMMANDS = 212;
    MSG_STATSCOMMANDS = '%s %d';
            {%s = <command>; %d = <count>}
    RPL_STATSCLINE = 213;
    MSG_STATSCLINE = 'C %s *  %d %s';
            {%s = <host>; %s = <name>; %d = <port>; %s = <class>}
    RPL_STATSNLINE = 214;
    MSG_STATSNLINE = 'N %s * %s %d %s';
            {%s = <host>; %s = <name>; %d = <port>; %s = <class>}
    RPL_STATSILINE = 215;
    MSG_STATSILINE = 'I %s * %s %d %s';
            {%s = <host>; %s = <name>; %d = <port>; %s = <class>}
    RPL_STATSKLINE = 216;
    MSG_STATSKLINE = 'K %s * %s %d %s';
            {%s = <host>; %s = <username>; %d = <port>; %s = <class>}
    RPL_STATSYLINE = 218;
    MSG_STATSYLINE = 'Y %s %d %d %d';
            {%s = <class>; %d = <ping frequency>; %d = <connect frequency>'
             %d = <max sendq>}
    RPL_ENDOFSTATS = 219;
    MSG_ENDOFSTATS = '%c :End of /STATS report';
            {%c = <stats letter>}
    RPL_STATSLLINE = 241;
    MSG_STATSLLINE = 'L %s * %s %d';
            {%s = <hostmask>; %s = <servername>; %d = <maxdepth>}
    RPL_STATSUPTIME = 242;
    MSG_STATSUPTIME = ':Server Up %d days %d:%02d:%02d';
    RPL_STATSOLINE = 243;
    MSG_STATSOLINE = 'O %s * %s';
            {%s = <hostmask>; %s = <name>}
    RPL_STATSHLINE = 244;
    MSG_STATSHLINE = 'H %s * %s';
            {%s = <hostmask>; %s = <name>}
    RPL_UMODEIS = 221;
    MSG_UMODEIS = '%s';
            {%s = <user mode string>
                    - To answer a query about a client's own mode,
                      RPL_UMODEIS is sent back.
            }
    RPL_LUSERCLIENT = 251;
    MSG_LUSERCLIENT = ':There are %d users and %d invisible on %d servers';
            {%d = <integer>; %d = <integer>; %d = <integer>}
    RPL_LUSEROP = 252;
    MSG_LUSEROP = '%d :operator(s) online';
            {%d = <integer>}
    RPL_LUSERUNKNOWN = 253;
    MSG_LUSERUNKNOWN = '%d :unknown connection(s)';
            {%d = <integer>}
    RPL_LUSERCHANNELS = 254;
    MSG_LUSERCHANNELS = '%d :channels formed';
            {%d = <integer>}

// Added by Christiano Becker on 08-27-2003 @ 14:59:32

    RPL_LUSERLOCALUSERS = 265;
    MSG_LUSERLOCALUSERS = ':Current local users: %d';
    RPL_LUSERGLOBALUSERS = 266;
    MSG_LUSERGLOBALUSERS = ':Current global users: %d';
// End of addition

    RPL_LUSERME = 255;
    MSG_LUSERME = ':I have %d clients and %d servers';
            {%d = <integer>; %d = <integer>
                    - In processing an LUSERS message, the server
                      sends a set of replies from RPL_LUSERCLIENT,
                      RPL_LUSEROP, RPL_USERUNKNOWN,
                      RPL_LUSERCHANNELS and RPL_LUSERME.  When
                      replying, a server must send back
                      RPL_LUSERCLIENT and RPL_LUSERME.  The other
                      replies are only sent back if a non-zero count
                      is found for them.
            }
    RPL_ADMINME = 256;
    MSG_ADMINME = '%s :Administrative info';
            {%s = <server>}
    RPL_ADMINLOC1 = 257;
    MSG_ADMINLOC1 = ':%s';
            {%s = <admin info>}
    RPL_ADMINLOC2 = 258;
    MSG_ADMINLOC2 = ':%s';
            {%s = <admin info>}
    RPL_ADMINEMAIL = 259;
    MSG_ADMINEMAIL = ':%s';
            {%s = <admin info>
                    - When replying to an ADMIN message, a server
                      is expected to use replies RLP_ADMINME
                      through to RPL_ADMINEMAIL and provide a text
                      message with each.  For RPL_ADMINLOC1 a
                      description of what city, state and country
                      the server is in is expected, followed by
                      details of the university and department
                      (RPL_ADMINLOC2) and finally the administrative
                      contact for the server (an email address here
                      is required) in RPL_ADMINEMAIL.
            }
    RPL_TRACECLASS      = 209;
    RPL_STATSQLINE      = 217;
    RPL_SERVICEINFO     = 231;
    RPL_ENDOFSERVICES   = 232;
    RPL_SERVICE         = 233;
    RPL_SERVLIST        = 234;
    RPL_SERVLISTEND     = 235;
    RPL_WHOISCHANOP     = 316;
    RPL_KILLDONE        = 361;
    RPL_CLOSING         = 362;
    RPL_CLOSEEND        = 363;
    RPL_INFOSTART       = 373;
    MSG_INFOSTART = ':Server INFO';
    RPL_MYPORTIS        = 384;
    ERR_YOUWILLBEBANNED = 466;
    ERR_BADCHANMASK     = 476;
    ERR_NOSERVICEHOST   = 492;
implementation
end.                         